'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _defineProperty = require('babel-runtime/core-js/object/define-property');

var _defineProperty2 = _interopRequireDefault(_defineProperty);

exports.default = mixinLinkGetters;

var _collection = require('lodash/collection');

var _object = require('lodash/object');

var _function = require('lodash/function');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @private
 * Sets getters on links for a given response
 */
function mixinLinkGetters(items, includes) {
  (0, _collection.each)(items, function (item) {
    return setLocalizedFieldGetters(item.fields, includes, !!item.sys.locale);
  });
}

/**
 * @private
 * If a field does not have a locale defined in sys, the content of that field
 * is an object where the keys are each available locale, and we need to iterate
 * over each of those
 */
function setLocalizedFieldGetters(fields, includes, hasLocale) {
  if (hasLocale) {
    setFieldGettersForFields(fields, includes);
  } else {
    (0, _collection.each)(fields, function (localizedField) {
      return setFieldGettersForFields(localizedField, includes);
    });
  }
}

/**
 * @private
 * Sets getters on each link field or list of link fields for each item
 */
function setFieldGettersForFields(fields, includes) {
  (0, _collection.each)(fields, function (field, fieldKey) {
    if (Array.isArray(field)) {
      addGetterForLinkArray(field, fieldKey, fields, includes);
    } else {
      addGetterForLink(field, fieldKey, fields, includes);
    }
  });
}

/**
 * @private
 * Sets a getter which resolves the link of the given fieldKey in fields
 */
function addGetterForLink(field, fieldKey, fields, includes) {
  if ((0, _object.get)(field, 'sys.type') === 'Link') {
    (0, _defineProperty2.default)(fields, fieldKey, {
      get: (0, _function.memoize)((0, _function.partial)(linkGetter, includes, field))
    });
  }
}

/**
 * @private
 * Sets a getter which resolves the array of links of the given fieldKey in fields
 */
function addGetterForLinkArray(listField, fieldKey, fields, includes) {
  if ((0, _object.get)(listField[0], 'sys.type') === 'Link') {
    (0, _defineProperty2.default)(fields, fieldKey, {
      get: (0, _function.memoize)(function () {
        return (0, _collection.map)(listField, (0, _function.partial)(linkGetter, includes));
      })
    });
  }
}

/**
 * @private
 * Looks for given link field in includes.
 * If linked entity is not found, it returns the original link.
 */
function linkGetter(includes, field) {
  var link = (0, _collection.find)(includes[field.sys.linkType], ['sys.id', field.sys.id]);
  if (link && link.fields) {
    setLocalizedFieldGetters(link.fields, includes, !!link.sys.locale);
    return link;
  }
  return field;
}